TH32CSFlags

Struct TH32CSFlags 

pub struct TH32CSFlags { /* private fields */ }

Implementations

Source

impl TH32CSFlags

pub const INHERIT: TH32CSFlags

pub const SNAPALL: TH32CSFlags

pub const SNAPHEAPLIST: TH32CSFlags

pub const SNAPMODULE: TH32CSFlags

pub const SNAPMODULE32: TH32CSFlags

pub const SNAPPROCESS: TH32CSFlags

pub const SNAPTHREAD: TH32CSFlags

pub const fn empty() -> TH32CSFlags

Returns an empty set of flags

pub const fn all() -> TH32CSFlags

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<TH32CSFlags>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> TH32CSFlags

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> TH32CSFlags

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: TH32CSFlags) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: TH32CSFlags) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: TH32CSFlags)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: TH32CSFlags)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: TH32CSFlags)

Toggles the specified flags in-place.

pub fn set(&mut self, other: TH32CSFlags, value: bool)

Inserts or removes the specified flags depending on the passed value.