pub struct SymlinkFlags { /* private fields */ }Implementations
Sourceimpl SymlinkFlags
impl SymlinkFlags
pub const NONE: SymlinkFlags
Sourcepub const DIRECTORY: SymlinkFlags
pub const DIRECTORY: SymlinkFlags
SYMBOLIC_LINK_FLAG_DIRECTORY
Sourcepub const ALLOW_UNPRIVILEGED_CREAT: SymlinkFlags
pub const ALLOW_UNPRIVILEGED_CREAT: SymlinkFlags
SYMBOLIC_LINK_FLAG_ALLOW_UNPRIVILEGED_CREATE
Sourcepub const fn empty() -> SymlinkFlags
pub const fn empty() -> SymlinkFlags
Returns an empty set of flags
Sourcepub const fn all() -> SymlinkFlags
pub const fn all() -> SymlinkFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: DWORD) -> Option<SymlinkFlags>
pub fn from_bits(bits: DWORD) -> Option<SymlinkFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: DWORD) -> SymlinkFlags
pub const fn from_bits_truncate(bits: DWORD) -> SymlinkFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: DWORD) -> SymlinkFlags
pub const unsafe fn from_bits_unchecked(bits: DWORD) -> SymlinkFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: SymlinkFlags) -> bool
pub const fn intersects(&self, other: SymlinkFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: SymlinkFlags) -> bool
pub const fn contains(&self, other: SymlinkFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: SymlinkFlags)
pub fn insert(&mut self, other: SymlinkFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: SymlinkFlags)
pub fn remove(&mut self, other: SymlinkFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: SymlinkFlags)
pub fn toggle(&mut self, other: SymlinkFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: SymlinkFlags, value: bool)
pub fn set(&mut self, other: SymlinkFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.