pub struct FileAccessRights { /* private fields */ }Implementations
Sourceimpl FileAccessRights
impl FileAccessRights
pub const FILE_ADD_FILE: FileAccessRights
pub const FILE_ADD_SUBDIRECTORY: FileAccessRights
pub const FILE_ALL_ACCESS: FileAccessRights
pub const FILE_APPEND_DATA: FileAccessRights
pub const FILE_CREATE_PIPE_INSTANCE: FileAccessRights
pub const FILE_DELETE_CHILD: FileAccessRights
pub const FILE_EXECUTE: FileAccessRights
pub const FILE_LIST_DIRECTORY: FileAccessRights
pub const FILE_READ_ATTRIBUTES: FileAccessRights
pub const FILE_READ_DATA: FileAccessRights
pub const FILE_READ_EA: FileAccessRights
pub const FILE_TRAVERSE: FileAccessRights
pub const FILE_WRITE_ATTRIBUTES: FileAccessRights
pub const FILE_WRITE_DATA: FileAccessRights
pub const FILE_WRITE_EA: FileAccessRights
pub const STANDARD_RIGHTS_READ: FileAccessRights
pub const STANDARD_RIGHTS_WRITE: FileAccessRights
pub const FILE_GENERIC_EXECUTE: FileAccessRights
pub const FILE_GENERIC_READ: FileAccessRights
pub const FILE_GENERIC_WRITE: FileAccessRights
pub const SYNCHRONIZE: FileAccessRights
pub const GENERIC_ALL: FileAccessRights
pub const GENERIC_EXECUTE: FileAccessRights
pub const GENERIC_READ: FileAccessRights
pub const GENERIC_WRITE: FileAccessRights
Sourcepub const fn empty() -> FileAccessRights
pub const fn empty() -> FileAccessRights
Returns an empty set of flags
Sourcepub const fn all() -> FileAccessRights
pub const fn all() -> FileAccessRights
Returns the set containing all flags.
Sourcepub fn from_bits(bits: DWORD) -> Option<FileAccessRights>
pub fn from_bits(bits: DWORD) -> Option<FileAccessRights>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: DWORD) -> FileAccessRights
pub const fn from_bits_truncate(bits: DWORD) -> FileAccessRights
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: DWORD) -> FileAccessRights
pub const unsafe fn from_bits_unchecked(bits: DWORD) -> FileAccessRights
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: FileAccessRights) -> bool
pub const fn intersects(&self, other: FileAccessRights) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: FileAccessRights) -> bool
pub const fn contains(&self, other: FileAccessRights) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: FileAccessRights)
pub fn insert(&mut self, other: FileAccessRights)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: FileAccessRights)
pub fn remove(&mut self, other: FileAccessRights)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: FileAccessRights)
pub fn toggle(&mut self, other: FileAccessRights)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: FileAccessRights, value: bool)
pub fn set(&mut self, other: FileAccessRights, value: bool)
Inserts or removes the specified flags depending on the passed value.