pub struct TH32CSFlags { /* private fields */ }Implementations
Sourceimpl TH32CSFlags
impl TH32CSFlags
pub const INHERIT: TH32CSFlags
pub const SNAPALL: TH32CSFlags
pub const SNAPHEAPLIST: TH32CSFlags
pub const SNAPMODULE: TH32CSFlags
pub const SNAPMODULE32: TH32CSFlags
pub const SNAPPROCESS: TH32CSFlags
pub const SNAPTHREAD: TH32CSFlags
Sourcepub const fn empty() -> TH32CSFlags
pub const fn empty() -> TH32CSFlags
Returns an empty set of flags
Sourcepub const fn all() -> TH32CSFlags
pub const fn all() -> TH32CSFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<TH32CSFlags>
pub fn from_bits(bits: u32) -> Option<TH32CSFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> TH32CSFlags
pub const fn from_bits_truncate(bits: u32) -> TH32CSFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TH32CSFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TH32CSFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: TH32CSFlags) -> bool
pub const fn intersects(&self, other: TH32CSFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: TH32CSFlags) -> bool
pub const fn contains(&self, other: TH32CSFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: TH32CSFlags)
pub fn insert(&mut self, other: TH32CSFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: TH32CSFlags)
pub fn remove(&mut self, other: TH32CSFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: TH32CSFlags)
pub fn toggle(&mut self, other: TH32CSFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: TH32CSFlags, value: bool)
pub fn set(&mut self, other: TH32CSFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.